@@ -1,2 +1,2 @@
 def divide_by_three(num):
-    return num / 3
+    return num*2 / 3
